<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Nivå %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Inga</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Ingen omslagsbild</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klart</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Skriv in den nya filändelsen:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Skapa ny filändelse</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Ny</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Radera</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation>Katalog som innehåller videofiler</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation>Denna katalog måste finnas och användaren som kör MythVideo måste åtminstone ha läsrättigheter i det.</translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation>Startnivå för barnlås</translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation>4 - Högsta</translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation>1 - Lägsta</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation>Detta är nivån som barnlåset startar på. Filmer som har en nivå lägre än eller lika med denna kommer att visas i listorna medans filer som har en högre nivå kommer att döljas tills rätt PIN-kod har matats in.</translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation>PIN-kod för barnlås</translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation>Om denna funktion är aktiverad måste PIN-koden matas in för att kunna återvända till denna vy. Du har härmed blivit varnad.</translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation>Visa okända filtyper</translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation>Om funktionen är aktiverad, kommer alla filer som ligger under den tidigare specifierade katalogen att visas, såvida inte deras filändelse har satts upp för att ignoreras.</translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation>Visa även filer som inte sökts upp i filmhanteraren</translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation>Om denna funktion är aktiverad kommer videolistvyn att visa alla relevanta filer som ligger under den tidigare specifierade katalogen och inte bara de filmer som har sökts upp under Filmhanteraren.</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Standardspelare</translation>
    </message>
    <message>
        <source>General Settings</source>
        <translation>Generella inställningar</translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation>Inställningar för spelare</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>PIN-kod (barnlås):</translation>
    </message>
    <message>
        <source>Searching for video files</source>
        <translation>Söker efter videofiler</translation>
    </message>
    <message>
        <source>Updating video database</source>
        <translation>Uppdaterar filmdatabasen</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Ingen omslagsbild</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Inga</translation>
    </message>
    <message>
        <source>NR</source>
        <translation>Oklassificerad</translation>
    </message>
    <message>
        <source>Unknown Rating</source>
        <translation>Okänd rankning</translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation>Nyscannade filer är bläddringsbara som standard</translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation>Nyscannade filer i Video Manager kommer att markeras som bläddringsbara och kommer att synas i bläddra-menyn.</translation>
    </message>
    <message>
        <source>New category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation>Kommando för att söka efter filmlistor</translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation>Detta kommando måste kunna exekveras av användaren som kör MythVideo.</translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation>Kommando för att söka efter filmposters</translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation>Kommando för att hämta filminformation</translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation>Katalog innehållande filmposters</translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation>Katalogen måste existers och användaren som kör MythVideo måste ha skriv/läs-rättigheter till den.</translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation>Videohanterare</translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation>Kunde inte hämta poster</translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation>En filmposter finns för denna filmen men MythTVideo kunde inte hämta den inom rimlig tid.</translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation>Denna PIN-kod används för att låsa upp barnlåset för filmer. Om ingen kod anges kommer barnlåset att vara avslaget. Om du slår på barnlåset är det lättast om bara siffror används.</translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation>Lås även vy för barnlåskonfigurationen</translation>
    </message>
    <message>
        <source>Default View</source>
        <translation>Standardvy</translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation>Galleri</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Bläddrare</translation>
    </message>
    <message>
        <source>Listings</source>
        <translation>Listningar</translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation>Detta är standardkommandot för uppspelning av filer. &apos;Internal&apos; använder Myth&apos;s egna uppspelningsmetod.</translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation>Rader att visa</translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation>Kolumner att visa</translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation>Visa titel under miniatyrbild</translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation>Om denna funktion aktiveras kommer texten att göra miniatyrbilderna mindre.</translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation>Bibehåll aspekt på miniatyrbilder</translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation>Låt miniatyrbilderna bibehålla sin ursprungliga aspekt, annars skalas de för att matcha storleken på bakgrundsikonen.</translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation>Videogalleri</translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation>Standardvy för MythVideo. Andra vyer kan nås genom popup-menyn tillgänglig via MENY-knappen.</translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Regissör:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>År:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Klassificering:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Barnlåsnivå:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Blädderbar:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Längd:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Handling:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Filnamn:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Fil för omslagsbild:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>IMDB-nummer:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>hämtar data...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ letar efter ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Mata in IMDB-nummer</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>laddar...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>Inga filmer hittades</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Regi:</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Fil:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Spelare:</translation>
    </message>
    <message>
        <source>PL </source>
        <translation>Nivå </translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>Filassociationer för videospelaren</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Filändelse:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Kommando:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Använd standardspelare:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignorera:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Redigera filminformation</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Namn:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Barnlås:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>Fil som alltid spelas efter denna:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Inkludera vid bläddring:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Omslagsbild:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Kommando för uppspelning:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/sökväg/till/bilden.jpg</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>Filtrerar videolistan</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>Land:</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>År:</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>Speltid:</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>Användarbetyg:</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation>Bläddra:</translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>Sortera efter:</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation>Ingen video</translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>VÄLJ: Ändra</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation>Barnlås</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Nivå</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>År</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>Speltid</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>Användarbetyg</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - Handlingsmeny</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Upp/Ner, Page Up/Down: Bläddra   MENY: Inställningar   INFO: Handlingsmeny</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>Spela fil efter detta:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 av %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Inga filmer</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation>Ingen rankning tillgänglig.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Spela upp denna film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Visa full beskrivning</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtervisning</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>Byt till bläddringsläge</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Byt till galleriläge</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>Byt till listläge</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Välj åtgärd</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation>PIN-kod (barnlås):</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>Resultat av detta filter: %1 video(s)</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>Resultat av detta filter: Inga videos</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Alla</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Spara som standard</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Klar</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation>Filtervisning</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Spela upp denna film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Visa full beskrivning</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>Visa detaljer</translation>
    </message>
    <message>
        <source>Plain View</source>
        <translation>Vanlig vy</translation>
    </message>
    <message>
        <source>Folder View</source>
        <translation>Katalogvy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>Skriv in IMDB-numret manuellt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nej</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation>Ingen omslagsbild</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Okänd</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <source>NR</source>
        <translation>Oklassificerad</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>borttagning misslyckades</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Välj åtgärd:</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>Ändra metadata</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>Sök IMDB</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>Återställ metadata</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation>Växla bläddringsbar</translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>Ta bort film</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtervisning</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>Ta bort denna fil?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation>Ingen rankning tillgänglig.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuter</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation>PIN-kod (barnlås):</translation>
    </message>
    <message>
        <source>No files found</source>
        <translation>Inga filer funna</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Välj åtgärd</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Spela upp denna film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Visa full beskrivning</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Filtervisning</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>Byt till bläddringsläge</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Byt till galleriläge</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
</TS>
